#[non_exhaustive]pub struct UpdateWorkGroupInputBuilder { /* private fields */ }Expand description
A builder for UpdateWorkGroupInput.
Implementations
Sourceimpl UpdateWorkGroupInputBuilder
impl UpdateWorkGroupInputBuilder
Sourcepub fn work_group(self, input: impl Into<String>) -> Self
pub fn work_group(self, input: impl Into<String>) -> Self
The specified workgroup that will be updated.
This field is required.Sourcepub fn set_work_group(self, input: Option<String>) -> Self
pub fn set_work_group(self, input: Option<String>) -> Self
The specified workgroup that will be updated.
Sourcepub fn get_work_group(&self) -> &Option<String>
pub fn get_work_group(&self) -> &Option<String>
The specified workgroup that will be updated.
Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
The workgroup description.
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
The workgroup description.
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
The workgroup description.
Sourcepub fn configuration_updates(self, input: WorkGroupConfigurationUpdates) -> Self
pub fn configuration_updates(self, input: WorkGroupConfigurationUpdates) -> Self
Contains configuration updates for an Athena SQL workgroup.
Sourcepub fn set_configuration_updates(
self,
input: Option<WorkGroupConfigurationUpdates>,
) -> Self
pub fn set_configuration_updates( self, input: Option<WorkGroupConfigurationUpdates>, ) -> Self
Contains configuration updates for an Athena SQL workgroup.
Sourcepub fn get_configuration_updates(
&self,
) -> &Option<WorkGroupConfigurationUpdates>
pub fn get_configuration_updates( &self, ) -> &Option<WorkGroupConfigurationUpdates>
Contains configuration updates for an Athena SQL workgroup.
Sourcepub fn state(self, input: WorkGroupState) -> Self
pub fn state(self, input: WorkGroupState) -> Self
The workgroup state that will be updated for the given workgroup.
Sourcepub fn set_state(self, input: Option<WorkGroupState>) -> Self
pub fn set_state(self, input: Option<WorkGroupState>) -> Self
The workgroup state that will be updated for the given workgroup.
Sourcepub fn get_state(&self) -> &Option<WorkGroupState>
pub fn get_state(&self) -> &Option<WorkGroupState>
The workgroup state that will be updated for the given workgroup.
Sourcepub fn build(self) -> Result<UpdateWorkGroupInput, BuildError>
pub fn build(self) -> Result<UpdateWorkGroupInput, BuildError>
Consumes the builder and constructs a UpdateWorkGroupInput.
Sourceimpl UpdateWorkGroupInputBuilder
impl UpdateWorkGroupInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<UpdateWorkGroupOutput, SdkError<UpdateWorkGroupError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<UpdateWorkGroupOutput, SdkError<UpdateWorkGroupError, HttpResponse>>
Sends a request with this input using the given client.